@@ -52,8 +52,8 @@ from .metaquote.platafrom import metatrader
 
 # local indicators calculate
 
-from .technicals.indicator_local import indicators
-from .technicals.charts import Renko, PnF, LineBreak
+from .technicalslocal.taindicators import indicators
+from .technicalslocal.charts import Renko, PnF, LineBreak
 
 
 # iq option api
